// Copyright (c) Jupyter Development Team.
// Distributed under the terms of the Modified BSD License.
'use strict';
import { Panel } from '@lumino/widgets';
import { createNbdimeMergeView } from '../../common/mergeview';
import { CollapsiblePanel } from '../../common/collapsiblepanel';
const ROOT_METADATA_CLASS = 'jp-Metadata-diff';
/**
 * MetadataWidget for changes to Notebook-level metadata
 */
export class MetadataMergeWidget extends Panel {
    constructor({ model, editorFactory, }) {
        super();
        this._editorFactory = editorFactory;
        this._model = model;
        this.addClass(ROOT_METADATA_CLASS);
        this.init();
    }
    init() {
        let model = this._model;
        // We know/assume that MetadataMergeModel never has
        // null values for local/remote:
        this.view = createNbdimeMergeView({
            remote: model.remote,
            local: model.local,
            merged: model.merged,
            factory: this._editorFactory,
        });
        let wrapper = new CollapsiblePanel(this.view, 'Notebook metadata changed', true);
        this.addWidget(wrapper);
    }
    validateMerged(candidate) {
        let text = this.view.getMergedValue();
        if (JSON.stringify(candidate) !== text) {
            // This will need to be validated server side,
            // and should not be touched by client side
            // (structure might differ from assumed form)
            candidate = JSON.parse(text);
        }
        return candidate;
    }
}
//# sourceMappingURL=metadata.js.map